{% extends "rest_framework/base.html" %}
{% load static %}

{% block title %}
Irekua API
{% endblock %}

{% block branding %}
    <a class="navbar-brand" rel="nofollow" href="#">
      Irekua API
    </a>
    <a class="navbar-brand" rel="nofollow" href="#">
      <img src="https://www.biodiversidad.gob.mx/assets/images/logo.png" height="100%">
    </a>
{% endblock %}

{% block style %}
  {% block bootstrap_theme %}
    <link rel="stylesheet" type="text/css" href="{% static "rest_framework/css/bootstrap.min.css" %}"/>
    <link rel="stylesheet" type="text/css" href="{% static "rest_framework/css/bootstrap-tweaks.css" %}"/>
  {% endblock %}

  <link rel="stylesheet" type="text/css" href="{% static "rest_framework/css/prettify.css" %}"/>
  <link rel="stylesheet" type="text/css" href="{% static "rest_framework/css/default.css" %}"/>
  <link rel="stylesheet" type="text/css" href="{% static "irekua_rest_api/css/default.css" %}"/>
  {% if code_style %}<style>{{ code_style }}</style>{% endif %}
{% endblock %}
